package com.evobms.project.vehicledata.mapper;

import java.util.Date;
import java.util.List;
import com.evobms.project.vehicledata.domain.VehicleData;
import org.apache.ibatis.annotations.Param;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 整车数据Mapper接口
 *
 * @author 田志阳
 * @date 2025-11-15
 */
public interface VehicleDataMapper extends BaseMapper<VehicleData>
{
    /**
     * 查询整车数据
     *
     * @param id 整车数据主键
     * @return 整车数据
     */
    public VehicleData selectVehicleDataById(Long id);

    /**
     * 查询整车数据列表
     *
     * @param vehicleData 整车数据
     * @return 整车数据集合
     */
    public List<VehicleData> selectVehicleDataList(VehicleData vehicleData);

    /**
     * 新增整车数据
     *
     * @param vehicleData 整车数据
     * @return 结果
     */
    public int insertVehicleData(VehicleData vehicleData);

    /**
     * 修改整车数据
     *
     * @param vehicleData 整车数据
     * @return 结果
     */
    public int updateVehicleData(VehicleData vehicleData);

    /**
     * 删除整车数据
     *
     * @param id 整车数据主键
     * @return 结果
     */
    public int deleteVehicleDataById(Long id);

    /**
     * 批量删除整车数据
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteVehicleDataByIds(Long[] ids);

    List<VehicleData> selectByDeviceAndStartTime(@Param("deviceId") String deviceId, @Param("startTime") Date startTime);

    VehicleData selectLatestByDeviceId(String deviceId);
}
